@@ -5,17 +5,7 @@
  License, v. 2.0. If a copy of the MPL was not distributed with this
  file, You can obtain one at http://mozilla.org/MPL/2.0/.
 """
-__version__ = 0.3
-
-try:
-    from ctypes import windll
-    IS_ADMIN = bool(windll.advpack.IsNTAdmin(0, None))
-except ImportError:
-    raise ImportError('flair is only importable on Windows')
-else:
-    if not IS_ADMIN:
-        raise ImportError('flair must be run as Administrator')
-    del windll
+__version__ = 0.4
 
 from . import hook, augment, inspect
 from .inspect import events
